From c27941663bf568a0b49662a38e43a4e972bad47f Mon Sep 17 00:00:00 2001
From: cfoe <cfoe@ispconfig3>
Date: Tue, 07 Aug 2012 02:29:14 -0400
Subject: [PATCH] added support for extended generatePassword function

---
 interface/web/sites/web_domain_del.php |   41 ++++++++++++++++++++++++++++++++++++++---
 1 files changed, 38 insertions(+), 3 deletions(-)

diff --git a/interface/web/sites/web_domain_del.php b/interface/web/sites/web_domain_del.php
index 867d1f4..f84f4f1 100644
--- a/interface/web/sites/web_domain_del.php
+++ b/interface/web/sites/web_domain_del.php
@@ -55,23 +55,58 @@
 		
 		if($app->tform->checkPerm($this->id,'d') == false) $app->error($app->lng('error_no_delete_permission'));
 		
-		// Delete all records that belog to this zone.
+		//* Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT domain_id FROM web_domain WHERE parent_domain_id = '".intval($this->id)."' AND type != 'vhost'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('web_domain','domain_id',$rec['domain_id']);
 		}
 		
-		// Delete all records that belog to this zone.
+		//* Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT ftp_user_id FROM ftp_user WHERE parent_domain_id = '".intval($this->id)."'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('ftp_user','ftp_user_id',$rec['ftp_user_id']);
 		}
 		
 		// Delete all records that belog to this zone.
 		$records = $app->db->queryAllRecords("SELECT shell_user_id FROM shell_user WHERE parent_domain_id = '".intval($this->id)."'");
 		foreach($records as $rec) {
 			$app->db->datalogDelete('shell_user','shell_user_id',$rec['shell_user_id']);
 		}
+        
+        //* Delete all records that belog to this web.
+        $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            $app->db->datalogDelete('cron','id',$rec['id']);
+        }
+		
+		//* Delete all records that belog to this web.
+        $records = $app->db->queryAllRecords("SELECT id FROM cron WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            $app->db->datalogDelete('cron','id',$rec['id']);
+        }
+		
+		//* Delete all records that belog to this web
+        $records = $app->db->queryAllRecords("SELECT webdav_user_id FROM webdav_user WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            $app->db->datalogDelete('webdav_user','webdav_user_id',$rec['webdav_user_id']);
+        }
+		
+		//* Delete all records that belog to this web
+        $records = $app->db->queryAllRecords("SELECT backup_id FROM web_backup WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            $app->db->datalogDelete('web_backup','backup_id',$rec['backup_id']);
+        }
+		
+		//* Delete all web folders
+        $records = $app->db->queryAllRecords("SELECT web_folder_id FROM web_folder WHERE parent_domain_id = '".intval($this->id)."'");
+        foreach($records as $rec) {
+            //* Delete all web folder users
+			$records2 = $app->db->queryAllRecords("SELECT web_folder_user_id FROM web_folder_user WHERE web_folder_id = '".$rec['web_folder_id']."'");
+			foreach($records2 as $rec2) {
+				$app->db->datalogDelete('web_folder_user','web_folder_user_id',$rec2['web_folder_user_id']);
+        }
+			$app->db->datalogDelete('web_folder','web_folder_id',$rec['web_folder_id']);
+        }
 	}
 }
 
@@ -55,23 +55,58 @@
 		}
 		
-		// Delete all records that belog to this zone.
+		//* Delete all records that belog to this web.
 		$records = $app->db->queryAllRecords("SELECT shell_user_id FROM shell_user WHERE parent_domain_id = '".intval($this->id)."'");
 		foreach($records as $rec) {

--
Gitblit v1.9.1